@@ -5,6 +5,7 @@
 import os
 import importlib
 import yaml
+import re
 import json
 from constant import *
 from arguments import Arguments
@@ -91,7 +92,7 @@ class PodspecTool(object):
                         url = urlList[0]
                         urlProtol, s1 = self.urlTool.URLProtocol(url)
                         host, port = self.urlTool.URLHostAndPort(url)
-                        replaceSource = replaceSource.replace(urlProtol, "ssh").replace(host, self.arguments.user + "@" + host + ":29418")
+                        replaceSource = replaceSource.replace(urlProtol, "ssh", 1).replace(host, self.arguments.user + "@" + host + ":29418")
                 replaceSource = str(replaceSource).strip("\n").strip("").split(",")[0].strip("}")
                 if LFSURL:
                     # if not self.urlTool.isURL(LFSURL):
@@ -321,6 +322,45 @@ class PodspecTool(object):
         if self.fileHandle.file_exist(originSpecName) and not self.fileHandle.file_exist(destinationSpecName):
             self.shell.excommand_until_done("cp -rf " + originSpecName + " " + destinationSpecName)
 
+    def podspecForPushHeaderRepo(self, podName, version, url):
+        content = self.podspecForPush(podName, version, url)
+        content = content.replace("ss.source_files = spec[:source_files]", "ss.source_files = spec[:public_header_files]")
+        if "ss.source_files = spec[:public_header_files]" not in content:
+            content = content.replace(",m,mm,c,cpp,cc", "").replace(",mm", "").replace(",m", "").replace(",cpp",
+                                                                                                                 "").replace(
+                ",cc", "").replace(",c", "")
+            content = re.sub("\.m\"", ".h\"", content, 0, flags=re.I)
+            content = re.sub("\.m\'", ".h\'", content, 0, flags=re.I)
+            if ".*" in content:
+                content = re.sub("\.\*", ".h", content, 0, flags=re.I)
+            if "/*\'" in content:
+                content = re.sub("/\*\'", "/*.h\'", content, 0, flags=re.I)
+            if "/*\"" in content:
+                content = re.sub("/\*\"", "/*.h\"", content, 0, flags=re.I)
+        content = re.sub("\t", "    ", content, 0, flags=re.I)
+        content = re.sub("s.preserve_paths *=( *((\'|\")(\D*?)(\'|\") *,? *\n))*", "", content, 1, flags=re.I)
+        content = re.sub("if spec\[:resource[s]?\]\n *ss.resources = spec\[:resource[s]?\]\n *end", "", content, 1,flags=re.I)
+        content = re.sub("if spec\[:resource_bundle[s]?\]\n *ss.resource_bundle[s]? = spec\[:resource_bundle[s]?\]\n *end", "",content, 1, flags=re.I)
+        return content
+
+    def podspecForPush(self, podName, version, url=""):
+        podspec_name = podName + ".podspec"
+        if not self.fileHandle.file_exist(podspec_name):
+            self.result.returnError("找不到文件" + podspec_name)
+        content = self.fileHandle.readFile(podspec_name)
+        # 修改版本
+        url = url.replace("http://git.lianjia.com", "http://gerrit.lianjia.com")
+        content = re.sub("s.version *= *(\'|\")(\D|.)+?(\'|\")", "s.version         = \"%s\"" % (version), content,
+                         1, flags=re.I)
+        # 修改homePage
+        content = re.sub("s.homepage *= *(\'|\")(\D*?)(\'|\")", "s.homepage         = \"%s\"" % (url), content, 1,
+                         flags=re.I)
+        # 修改url
+        content = re.sub("s.source *= {.*}?",
+                         "s.source           = { :git => \"%s\", :tag => s.name.to_s + \"-\" + s.version.to_s }" % (
+                             url), content, 1, flags=re.I)
+        return content
+
     def restorePodspec(self):
         destinationSpecName = self.arguments.podName + ".podspec"
         originSpecName = destinationSpecName + ".old"
