@@ -19,7 +19,7 @@ from Features.autoPackage import AutoPackage
 from Features.check import Check
 
 __author__ = "handa"
-__version__ = "1.0.21"
+__version__ = "1.0.30"
 
 
 def checkopts():
@@ -33,7 +33,7 @@ def checkopts():
         Tips.instance().showTips()
         Result.instance().returnError()
     # 先检查环境 TODO open
-    Env.instance().runtimeEnv()
+    # Env.instance().runtimeEnv()
     # 接着看参数
     arg = sys.argv[1]
     if arg == "version":
